@@ -1372,12 +1372,13 @@ class PluginButton (gtk.HBox):
 
     _plugin = None
 
-    def __init__ (self, plugin):
+    def __init__ (self, plugin, useMissingImage = False):
         gtk.HBox.__init__(self)
         self._plugin = plugin
 
-        image = Image (plugin.Name, ImagePlugin, size=32)
+        image = Image (plugin.Name, ImagePlugin, 32, useMissingImage)
         label = Label (plugin.ShortDesc, 120)
+        label.connect ('style-set', self.style_set)
         box = gtk.HBox ()
         box.set_spacing (5)
         box.pack_start (image, False, False)
@@ -1400,6 +1401,15 @@ class PluginButton (gtk.HBox):
 
         self.set_size_request (220, -1)
 
+    StyleBlock = 0
+
+    def style_set (self, widget, previous):
+        if self.StyleBlock > 0:
+            return
+        self.StyleBlock += 1
+        widget.modify_fg(gtk.STATE_NORMAL, widget.style.text[gtk.STATE_NORMAL])
+        self.StyleBlock -= 1
+
     def enable_plugin (self, widget):
 
         plugin = self._plugin
@@ -1447,6 +1457,7 @@ class PluginButton (gtk.HBox):
 class CategoryBox(gtk.VBox):
 
     _plugins = None
+    _unfiltered_plugins = None
     _buttons = None
     _context = None
     _name    = ""
@@ -1455,7 +1466,7 @@ class CategoryBox(gtk.VBox):
     _current_cols = 0
     _current_plugins = 0
 
-    def __init__ (self, context, name, plugins=None):
+    def __init__ (self, context, name, plugins=None, categoryIndex=0):
         gtk.VBox.__init__ (self)
 
         self.set_spacing (5)
@@ -1475,6 +1486,9 @@ class CategoryBox(gtk.VBox):
         self._name = name
         text = name or 'Uncategorized'
 
+        # Keep unfiltered list of plugins for correct background icon loading
+        self._unfiltered_plugins = self._plugins
+
         header = gtk.HBox ()
         header.set_border_width (5)
         header.set_spacing (10)
@@ -1489,9 +1503,12 @@ class CategoryBox(gtk.VBox):
         self._table = gtk.Table ()
         self._table.set_border_width (10)
 
+        # load icons now only for the first 3 categories
+        dontLoadIcons = (categoryIndex >= 3);
+
         self._buttons = []
         for plugin in self._plugins:
-            button = PluginButton(plugin)
+            button = PluginButton(plugin, dontLoadIcons)
             self._buttons.append(button)
 
         self._alignment = gtk.Alignment (0, 0, 1, 1)
@@ -1519,8 +1536,8 @@ class CategoryBox(gtk.VBox):
 
         return bool(self._plugins)
 
-    def rebuild_table (self, ncols):
-        if (ncols == self._current_cols
+    def rebuild_table (self, ncols, force = False):
+        if (not force and ncols == self._current_cols
         and len (self._plugins) == self._current_plugins):
             return
         self._current_cols = ncols
@@ -1548,6 +1565,9 @@ class CategoryBox(gtk.VBox):
     def get_plugins (self):
         return self._plugins
 
+    def get_unfiltered_plugins (self):
+        return self._unfiltered_plugins
+
 # Plugin Window
 #
 class PluginWindow(gtk.ScrolledWindow):
@@ -1594,12 +1614,10 @@ class PluginWindow(gtk.ScrolledWindow):
         self._not_found_box = NotFoundBox ()
 
         categories = sorted(self._categories, key=CategoryKeyFunc)
-        for category in categories:
+        for (i, category) in enumerate(categories):
             plugins = self._categories[category]
-            category_box = CategoryBox(context, category, plugins)
-            buttons = category_box.get_buttons ()
-            for button in buttons:
-                button.connect('clicked', self.show_plugin_page)
+            category_box = CategoryBox(context, category, plugins, i)
+            self.connect_buttons (category_box)
             self._boxes.append (category_box)
             self._box.pack_start (category_box, False, False)
 
@@ -1609,6 +1627,11 @@ class PluginWindow(gtk.ScrolledWindow):
         viewport.add (self._box)
         self.add (viewport)
 
+    def connect_buttons (self, category_box):
+        buttons = category_box.get_buttons ()
+        for button in buttons:
+            button.connect('clicked', self.show_plugin_page)
+
     def set_viewport_style (self, widget, previous):
         if self._style_block > 0:
             return
